import UIAbility from "@ohos:app.ability.UIAbility";
import type AbilityConstant from "@ohos:app.ability.AbilityConstant";
import type Want from "@ohos:app.ability.Want";
import hilog from "@ohos:hilog";
import type { Router, UIContext } from "@ohos:arkui.UIContext";
import type window from "@ohos:window";
import type { BusinessError } from "@ohos:base";
const DOMAIN_NUMBER: number = 0xFF00;
const TAG: string = '[EntryAbility]';
export default class EntryAbility extends UIAbility {
    funcAbilityWant: Want | undefined = undefined;
    uiContext: UIContext | undefined = undefined;
    onCreate(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        this.funcAbilityWant = want;
    }
    onDestroy(): void {
    }
    onWindowStageCreate(windowStage: window.WindowStage): void {
        // Main window is created, set main page for this ability
        hilog.info(DOMAIN_NUMBER, TAG, '%{public}s', 'Ability onWindowStageCreate');
        let url = 'pages/Index';
        if (this.funcAbilityWant?.parameters?.router && this.funcAbilityWant.parameters.router === 'funcA') {
            url = 'pages/Page_ColdStartUp';
        }
        hilog.info(DOMAIN_NUMBER, TAG, JSON.stringify(this.funcAbilityWant?.parameters));
        hilog.info(DOMAIN_NUMBER, TAG, url);
        windowStage.loadContent(url, (err, data) => {
            if (err.code) {
                hilog.error(DOMAIN_NUMBER, TAG, 'Failed to load the content. Cause: %{public}s', JSON.stringify(err) ?? '');
                return;
            }
            let windowClass: window.Window;
            windowStage.getMainWindow((err, data) => {
                if (err.code) {
                    hilog.error(DOMAIN_NUMBER, TAG, `Failed to obtain the main window. Code is ${err.code}, message is ${err.message}`);
                }
                windowClass = data;
                this.uiContext = windowClass.getUIContext();
            });
            hilog.info(DOMAIN_NUMBER, TAG, 'Succeeded in loading the content.');
        });
    }
    onNewWant(want: Want, launchParam: AbilityConstant.LaunchParam): void {
        if (want.parameters?.router && want.parameters.router === 'funcA') {
            let funcAUrl = 'pages/Page_HotStartUp';
            if (this.uiContext) {
                let router: Router = this.uiContext.getRouter();
                router.pushUrl({
                    url: funcAUrl
                }).catch((err: BusinessError) => {
                    hilog.error(DOMAIN_NUMBER, TAG, `Failed to push url. Code is ${err.code}, message is ${err.message}`);
                });
            }
        }
    }
    onWindowStageDestroy(): void {
        // Main window is destroyed, release UI related resources
    }
    onForeground(): void {
        // Ability has brought to foreground
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onForeground');
    }
    onBackground(): void {
        // Ability has back to background
        hilog.info(0x0000, 'testTag', '%{public}s', 'Ability onBackground');
    }
}
